@@ -35,7 +35,7 @@ class IpmiTimeoutError(Exception):
 class CompletionCodeError(Exception):
     """IPMI completion code not OK."""
 
-    def __init__(self, cc, cmd_id=None):
+    def __init__(self, cc, cmdid=None):
         self.cc = cc
         self.cc_desc = self.find_cc_desc(cc)
 
@@ -74,3 +74,12 @@ class DataNotFound(Exception):
 class HpmError(Exception):
     """HPM.1 error."""
     pass
+
+
+class IpmiConnectionError(Exception):
+    """Connection error."""
+    def __init__(self, msg=None):
+        self.msg = msg
+
+    def __str__(self):
+        return "{}".format(self.msg)
