@@ -29,7 +29,7 @@ from .errors import CompletionCodeError, HpmError, IpmiTimeoutError
 from .msgs import create_request_by_name
 from .msgs import constants
 from .utils import check_completion_code, bcd_search, chunks
-from .utils import py3dec_unic_bytes_fix, bytes2 as bytes
+from .utils import py3dec_unic_bytes_fix, py3_array_tobytes
 from .state import State
 from .fields import VersionField
 
@@ -68,7 +68,7 @@ class Hpm(object):
 
     @staticmethod
     def _get_component_count(components):
-        """Return the number of components"""
+        """Return the number of components."""
         return bin(components).count('1')
 
     def get_target_upgrade_capabilities(self):
@@ -109,7 +109,8 @@ class Hpm(object):
         self.send_message_with_name('AbortFirmwareUpgrade')
 
     def initiate_upgrade_action(self, components_mask, action):
-        """ Initiate Upgrade Action
+        """Initiate Upgrade Action.
+
         components:
         action:
             ACTION_BACKUP_COMPONENT = 0x00
@@ -117,7 +118,6 @@ class Hpm(object):
             ACTION_UPLOAD_FOR_UPGRADE = 0x02
             ACTION_UPLOAD_FOR_COMPARE = 0x03
         """
-
         if action in (ACTION_UPLOAD_FOR_UPGRADE, ACTION_UPLOAD_FOR_COMPARE):
             if self._get_component_count(components_mask) != 1:
                 raise HpmError("more than 1 component not support for action")
@@ -127,8 +127,7 @@ class Hpm(object):
 
     def initiate_upgrade_action_and_wait(self, components_mask, action,
                                          timeout=2, interval=0.1):
-        """ Initiate Upgrade Action and wait for
-            long running command. """
+        """Initiate Upgrade Action and wait for long running command."""
         try:
             self.initiate_upgrade_action(components_mask, action)
         except CompletionCodeError as e:
@@ -149,8 +148,7 @@ class Hpm(object):
         return 22
 
     def upload_binary(self, binary, timeout=2, interval=0.1, retry=3):
-        """ Upload all firmware blocks from binary and wait for
-            long running command. """
+        """Upload all firmware blocks from a binary."""
         block_number = 0
         block_size = self._determine_max_block_size()
 
@@ -180,8 +178,7 @@ class Hpm(object):
 
     def finish_upload_and_wait(self, component, length,
                                timeout=2, interval=0.1):
-        """ Finish the firmware upload process and wait for
-            long running command. """
+        """Finish, upload and for the firmware."""
         try:
             rsp = self.finish_firmware_upload(component, length)
             check_completion_code(rsp.completion_code)
@@ -203,7 +200,7 @@ class Hpm(object):
             try:
                 status = self.get_upgrade_status()
                 if status.command_in_progress is not expected_cmd \
-                        and status.command_in_progress is not 0x34:
+                        and status.command_in_progress != 0x34:
                     pass
                 if status.last_completion_code \
                         == CC_LONG_DURATION_CMD_IN_PROGRESS:
@@ -224,8 +221,7 @@ class Hpm(object):
 
     def activate_firmware_and_wait(self, rollback_override=None,
                                    timeout=2, interval=1):
-        """ Activate the new uploaded firmware and wait for
-            long running command. """
+        """Activate and wait for the new uploaded firmware."""
         try:
             self.activate_firmware(rollback_override)
         except CompletionCodeError as e:
@@ -474,9 +470,11 @@ class ComponentPropertyCurrentVersion(ComponentProperty):
 class ComponentPropertyDescriptionString(ComponentProperty):
 
     def _from_rsp_data(self, data):
-        self.description = py3dec_unic_bytes_fix(array('B', data).tostring())
+        descr = py3_array_tobytes(array('B', data))
+        descr = py3dec_unic_bytes_fix(descr)
         # strip '\x00'
-        self.description = self.description.replace('\0', '')
+        descr = descr.replace('\0', '')
+        self.description = descr
 
 
 class ComponentPropertyRollbackVersion(ComponentProperty):
@@ -612,7 +610,6 @@ class UpgradeActionRecord(object):
         if data:
             (self.action, self.components, self.checksum) \
                 = struct.unpack('BBB', data[0:3])
-            #    = struct.unpack('BBB', bytes(data[0:3], 'raw_unicode_escape'))
             self.length = 3
 
     @staticmethod
@@ -649,7 +646,6 @@ class UpgradeActionRecordUploadForUpgrade(UpgradeActionRecord):
     def __init__(self, data=None):
         UpgradeActionRecord.__init__(self, data)
         if data:
-            # data = bytes(data, 'raw_unicode_escape')
             self.firmware_version = \
                 VersionField(
                     data[3:3 + VersionField.VERSION_WITH_AUX_FIELD_LEN])
