@@ -21,7 +21,7 @@ from subprocess import Popen, PIPE
 from array import array
 
 from ..session import Session
-from ..errors import IpmiTimeoutError
+from ..errors import IpmiTimeoutError, IpmiConnectionError
 from ..logger import log
 from ..msgs import encode_message, decode_message, create_message
 from ..msgs.constants import CC_OK
@@ -53,6 +53,10 @@ class Ipmitool(object):
                 r"Unable to send RAW command \(.*rsp=(0x[0-9a-f]+)\)")
         self.re_timeout = re.compile(
                 r"Unable to send RAW command \(.*cmd=0x[0-9a-f]+\)")
+        self.re_unable_establish = re.compile(
+                r".*Unable to establish.*")
+        self.re_could_not_open = re.compile(
+                r".*Could not open device.*")
 
         self._session = None
 
@@ -104,12 +108,20 @@ class Ipmitool(object):
             if self.re_timeout.match(line):
                 raise IpmiTimeoutError()
 
+            # Check for unable to establish session
+            if self.re_unable_establish.match(line):
+                raise IpmiConnectionError('ipmitool: {}'.format(line))
+
             # Check for completion code
             match_completion_code = self.re_completion_code.match(line)
             if match_completion_code:
                 cc = int(match_completion_code.group(1), 16)
                 break
 
+            # Check for error opening ipmi device
+            if self.re_could_not_open.match(line):
+                raise RuntimeError('ipmitool failed: {}'.format(output))
+
             hexstr += line.replace('\r', '').strip() + ' '
 
         hexstr = hexstr.strip()
@@ -177,6 +189,8 @@ class Ipmitool(object):
     @staticmethod
     def _build_ipmitool_target(target):
         cmd = ''
+        if target is None:
+            return ''
         if target.routing is not None:
             # we have to do bridging here
             if len(target.routing) == 1:
@@ -253,7 +267,6 @@ class Ipmitool(object):
 
         return cmd
 
-
     @staticmethod
     def _run_ipmitool(cmd):
         """Legacy call of ipmitool (will be removed in future)."""
@@ -266,4 +279,7 @@ class Ipmitool(object):
                     child.returncode,
                     output)
 
+        if child.returncode == 127:
+            raise RuntimeError('ipmitool command not found')
+
         return output, child.returncode
