@@ -22,6 +22,7 @@ import sys
 import getopt
 import logging
 import traceback
+import pprint
 from array import array
 
 from collections import namedtuple
@@ -196,8 +197,9 @@ def cmd_sdr_list(ipmi, args):
                 (value, states) = ipmi.get_sensor_reading(s.number)
                 number = s.number
 
-            print_sdr_list_entry(s.id, number, s.device_id_string,
-                                 value, states)
+            id_string = getattr(s, 'device_id_string', None)
+
+            print_sdr_list_entry(s.id, number, id_string, value, states)
 
         except pyipmi.errors.CompletionCodeError as e:
             if s.type in (pyipmi.sdr.SDR_TYPE_COMPACT_SENSOR_RECORD,
@@ -376,10 +378,23 @@ def cmd_picmg_get_portstate(ipmi, args):
     print_link_state(p, s)
 
 
+def cmd_picmg_getpower_channel_status(ipmi, args):
+    ret = ipmi.get_power_channel_status(int(args[0]))
+    pprint.pprint(vars(ret))
+
+
 def cmd_picmg_frucontrol_cold_reset(ipmi, args):
     ipmi.fru_control_cold_reset(0)
 
 
+def cmd_picmg_send_pm_heartbeat(ipmi, args):
+    ipmi.send_pm_heartbeat()
+
+
+def cmd_picmg_send_channel_power(ipmi, args):
+    ipmi.send_channel_power(int(args[0]))
+
+
 def usage(toplevel=False):
     commands = []
     maxlen = 0
@@ -454,7 +469,7 @@ Aardvark interface options:
   power=<on|off>    Enable/disable target power
 
 Ipmitool interface options:
-  interface_type    Set the interface type to be used (lan, lanplus, serial)
+  interface_type    Set the interface type to be used (lan, lanplus, serial, open)
 
 Ipmbdev interface options:
   port=<path>       Specify path to Linux IPMB device (/dev/ipmb-0 by default)
@@ -548,7 +563,6 @@ def main():
             interface_name = a
         elif o == '-o':
             interface_options = a
-            #interface_options = a.split(',')
         else:
             assert False, 'unhandled option'
 
@@ -604,12 +618,12 @@ def main():
         if verbose:
             traceback.print_exc()
         sys.exit(1)
-    except pyipmi.errors.IpmiTimeoutError as e:
+    except pyipmi.errors.IpmiTimeoutError:
         print('Command timed out')
         if verbose:
             traceback.print_exc()
         sys.exit(1)
-    except KeyboardInterrupt as e:
+    except KeyboardInterrupt:
         if verbose:
             traceback.print_exc()
         sys.exit(1)
@@ -635,6 +649,9 @@ COMMANDS = (
         Command('picmg power get', cmd_picmg_get_power),
         Command('picmg portstate get', cmd_picmg_get_portstate),
         Command('picmg portstate getall', cmd_picmg_get_portstate_all),
+        Command('picmg channel status', cmd_picmg_getpower_channel_status),
+        Command('picmg send heartbeat', cmd_picmg_send_pm_heartbeat),
+        Command('picmg channel power', cmd_picmg_send_channel_power),
         Command('raw', cmd_raw),
         Command('hpm capabilities', cmd_hpm_capabilities),
         Command('hpm check', cmd_hpm_check_file),
