@@ -319,8 +319,40 @@ CMDID_HPM_QUERY_SELFTEST_RESULTS = 0x36
 CMDID_HPM_QUERY_ROLLBACK_STATUS = 0x37
 CMDID_HPM_INITIATE_MANUAL_ROLLBACK = 0x38
 
+# PICMG HPM.2 commands .. NetFn Group Extension (ID 0)
+CMDID_GET_LAN_ATTACH_CAPABILITIES = 0x3e
+
 # VITA commands .. NetFn Group Extension (ID 0x03)
 CMDID_VITA_GET_VSO_CAPABILITIES = 0x00
+CMDID_VITA_GET_CHASSIS_ADDRESS_TABLE_INFO = 0x01
+CMDID_VITA_GET_CHASSIS_IDENTIFIER = 0x02
+CMDID_VITA_SET_CHASSIS_IDENTIFIER = 0x03
+CMDID_VITA_FRU_CONTROL = 0x04
+CMDID_VITA_GET_FRU_LED_PROPERTIES = 0x05
+CMDID_VITA_GET_LED_COLOR_CAPABILITIES = 0x06
+CMDID_VITA_SET_FRU_LED_STATE = 0x07
+CMDID_VITA_GET_FRU_LED_STATE = 0x08
+CMDID_VITA_SET_IPMB_STATE = 0x09
+CMDID_VITA_SET_FRU_STATE_POLICY_BITS = 0x0a
+CMDID_VITA_GET_FRU_STATE_POLICY_BITS = 0x0b
+CMDID_VITA_SET_FRU_ACTIVATION = 0x0c
+CMDID_VITA_GET_DEVICE_LOCATOR_RECORD_ID = 0x0d
+CMDID_VITA_GET_FAN_SPEED_PROPERTIES = 0x14
+CMDID_VITA_SET_FAN_LEVEL = 0x15
+CMDID_VITA_GET_FAN_LEVEL = 0x16
+CMDID_VITA_GET_IPMB_LINK_INFO = 0x18
+CMDID_VITA_GET_CHASSIS_MANAGER_IPMB_ADDRESS = 0x1b
+CMDID_VITA_SET_FAN_POLICY = 0x1c
+CMDID_VITA_GET_FAN_POLICY = 0x1d
+CMDID_VITA_FRU_CONTROL_CAPABILITIES = 0x1e
+CMDID_VITA_FRU_INVENTROY_DEVICE_LOCK_CONTROL = 0x1f
+CMDID_VITA_FRU_INVENTROY_DEVICE_WRITE = 0x20
+CMDID_VITA_GET_CHASSIS_MANAGER_IP_ADDRESSES = 0x21
+CMDID_VITA_GET_FRU_ADDRESS_INFO = 0x40
+CMDID_VITA_GET_FRU_PERSISTENT_CONTROL = 0x41
+CMDID_VITA_SET_FRU_PERSISTENT_CONTROL = 0x42
+CMDID_VITA_FRU_PERSISTENT_CONTROL_CAPABILITIES = 0x43
+CMDID_VITA_GET_MANDATORY_SENSOR_NUMBERS = 0x44
 
 # DCMI commands .. NetFn Group Extension (ID 0xdc)
 CMDID_GET_DCMI_CAPABILITIES_INFO = 0x01
