@@ -304,6 +304,11 @@ class GroupExtensionIdentifier(UnsignedInt):
         UnsignedInt.__init__(self, name, 1, value)
 
 
+class EventMessageRevision(UnsignedInt):
+    def __init__(self, value=None):
+        UnsignedInt.__init__(self, 'event_message_rev', 1, value)
+
+
 class Message(object):
     RESERVED_FIELD_NAMES = ['cmdid', 'netfn', 'lun', 'group_extension']
 
@@ -339,6 +344,9 @@ class Message(object):
         raise NotImplementedError()
         # TODO walk along the properties..
 
+    def __str__(self):
+        return '{} [netfn={}, cmd={}, grp={}]'.format(type(self).__name__, self.netfn, self.cmdid, self.group_extension)
+
     def _create_fields(self):
         for field in self.__fields__:
             if field.name in self.RESERVED_FIELD_NAMES:
@@ -372,7 +380,7 @@ class Message(object):
     def _decode(self, data):
         """Decode the bytestring message."""
         if not hasattr(self, '__fields__'):
-            raise NotImplementedError('You have to overwrite this method')
+            return
 
         data = ByteBuffer(data)
         cc = None
@@ -398,6 +406,13 @@ class Message(object):
     group_extension = property(lambda s: s.__group_extension__)
 
 
-encode_message = lambda m: m._encode()
-decode_message = lambda m, d: m._decode(d)
-pack_message = lambda m: m._pack()
+def encode_message(msg):
+    return msg._encode()
+
+
+def decode_message(msg, data):
+    return msg._decode(data)
+
+
+def pack_message(msg):
+    return msg._pack()
