@@ -693,6 +693,30 @@ class GetLocationInformationRsp(PicmgMessage):
     )
 
 
+@register_message_class
+class SendPowerChannelControlReq(PicmgMessage):
+    __cmdid__ = constants.CMDID_POWER_CHANNEL_CONTROL
+    __netfn__ = constants.NETFN_GROUP_EXTENSION
+    __fields__ = (
+        GroupExtensionIdentifier('picmg_identifier', PICMG_IDENTIFIER),
+        UnsignedInt('channel', 1),
+        UnsignedInt('control', 1),
+        UnsignedInt('current_limit', 1),
+        UnsignedInt('primary_pm', 1),
+        UnsignedInt('backup_pm', 1),
+    )
+
+
+@register_message_class
+class SendPowerChannelControlRsp(PicmgMessage):
+    __cmdid__ = constants.CMDID_POWER_CHANNEL_CONTROL
+    __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
+    __fields__ = (
+        CompletionCode(),
+        GroupExtensionIdentifier('picmg_identifier', PICMG_IDENTIFIER),
+    )
+
+
 @register_message_class
 class GetPowerChannelStatusReq(PicmgMessage):
     __cmdid__ = constants.CMDID_GET_POWER_CHANNEL_STATUS
@@ -722,6 +746,30 @@ class GetPowerChannelStatusRsp(PicmgMessage):
     )
 
 
+@register_message_class
+class SendPmHeartbeatReq(PicmgMessage):
+    __cmdid__ = constants.CMDID_PM_HEARTBEAT
+    __netfn__ = constants.NETFN_GROUP_EXTENSION
+    __fields__ = (
+        GroupExtensionIdentifier('picmg_identifier', PICMG_IDENTIFIER),
+        UnsignedInt('timeout', 1),
+        Bitfield('ps1', 1,
+                 Bitfield.Bit('mch_1', 1, 0),
+                 Bitfield.Bit('mch_2', 1, 0),
+                 Bitfield.ReservedBit(6),),
+    )
+
+
+@register_message_class
+class SendPmHeartbeatRsp(PicmgMessage):
+    __cmdid__ = constants.CMDID_PM_HEARTBEAT
+    __netfn__ = constants.NETFN_GROUP_EXTENSION | 1
+    __fields__ = (
+        CompletionCode(),
+        GroupExtensionIdentifier('picmg_identifier', PICMG_IDENTIFIER),
+    )
+
+
 @register_message_class
 class GetTelcoAlarmCapabilityReq(PicmgMessage):
     __cmdid__ = constants.CMDID_GET_TELCO_ALARM_CAPABILITY
