@@ -21,6 +21,7 @@ import math
 from . import errors
 
 from .errors import DecodingError
+from .fields import SdrTypeLengthString
 from .utils import check_completion_code, ByteBuffer
 from .msgs import create_request_by_name
 
@@ -195,12 +196,13 @@ class SdrCommon(object):
             self.next_id = next_id
 
     def __str__(self):
-        if hasattr(self, 'devide_id_string'):
-            s = '["%-16s"] [%s]' % \
-            (self.device_id_string, ' '.join(['%02x' % b for b in self.data]))
+        if hasattr(self, 'device_id_string'):
+            s = '["%s"] [%s]' % \
+                 (self.device_id_string,
+                  ' '.join(['%02x' % b for b in self.data]))
         else:
             s = '[%s]' % \
-            (' '.join(['%02x' % b for b in self.data]))
+                 (' '.join(['%02x' % b for b in self.data]))
         return s
 
     def _common_header(self, data):
@@ -210,7 +212,7 @@ class SdrCommon(object):
             self.version = buffer.pop_unsigned_int(1)
             self.type = buffer.pop_unsigned_int(1)
             self.length = buffer.pop_unsigned_int(1)
-        except:
+        except IndexError:
             raise DecodingError('Invalid SDR length (%d)' % len(data))
 
     def _common_record_key(self, buffer):
@@ -223,9 +225,12 @@ class SdrCommon(object):
         self.entity_instance = buffer.pop_unsigned_int(1)
 
     def _device_id_string(self, buffer):
-        self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = \
-            buffer.pop_string(self.device_id_string_type_length & 0x3f)
+        self.device_id_string_type = (buffer[0] & 0xc0) >> 4
+        self.device_id_string_length = buffer[0] & 0x3f
+        field = SdrTypeLengthString(data=buffer[0:1+self.device_id_string_length])
+        self.device_id_string = field.string
+#        self.device_id_string = \
+#            buffer.pop_string(self.device_id_string_length & 0x3f)
 
     @staticmethod
     def from_data(data, next_id=None):
@@ -242,6 +247,8 @@ class SdrCommon(object):
                 SdrFruDeviceLocator,
             SDR_TYPE_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD:
                 SdrManagementControllerDeviceLocator,
+            SDR_TYPE_MANAGEMENT_CONTROLLER_CONFIRMATION_RECORD:
+                SdrManagementControllerConfirmationRecord,
             SDR_TYPE_OEM_SENSOR_RECORD:
                 SdrOEMSensorRecord,
         }.get(sdr_type, SdrUnknownSensorRecord)
@@ -262,7 +269,7 @@ class SdrFullSensorRecord(SdrCommon):
         super(SdrFullSensorRecord, self).__init__(data, next_id)
 
     def __str__(self):
-        s = '["%-16s"] [%s:%s] [%s]' \
+        s = '["%s"] [%s:%s] [%s]' \
                 % (self.device_id_string,
                    self.entity_id,
                    self.entity_instance,
@@ -281,7 +288,7 @@ class SdrFullSensorRecord(SdrCommon):
                 raw = -((raw & 0x7f) ^ 0x7f) - 1
         raw = float(raw)
 
-        return self.l((self.m * raw + (self.b * 10**self.k1)) * 10**self.k2)
+        return self.lin((self.m * raw + (self.b * 10**self.k1)) * 10**self.k2)
 
     def convert_sensor_value_to_raw(self, value):
         linearization = self.linearization & 0x7f
@@ -307,7 +314,7 @@ class SdrFullSensorRecord(SdrCommon):
         return raw
 
     @property
-    def l(self):
+    def lin(self):
         try:
             return {
                 L_LN: math.log,
@@ -488,7 +495,7 @@ class SdrCompactSensorRecord(SdrCommon):
         super(SdrCompactSensorRecord, self).__init__(data, next_id)
 
     def __str__(self):
-        s = '["%-16s"] [%s]' \
+        s = '["%s"] [%s]' \
             % (self.device_id_string,
                ' '.join(['%02x' % b for b in self.data]))
         return s
@@ -555,7 +562,7 @@ class SdrFruDeviceLocator(SdrCommon):
         super(SdrFruDeviceLocator, self).__init__(data, next_id)
 
     def __str__(self):
-        s = '["%-16s"] [%s]' \
+        s = '["%s"] [%s]' \
             % (self.device_id_string,
                ' '.join(['%02x' % b for b in self.data]))
         return s
@@ -583,7 +590,7 @@ class SdrManagementControllerDeviceLocator(SdrCommon):
                 data, next_id)
 
     def __str__(self):
-        s = '["%-16s"] [%s]' \
+        s = '["%s"] [%s]' \
             % (self.device_id_string,
                ' '.join(['%02x' % b for b in self.data]))
         return s
@@ -601,6 +608,27 @@ class SdrManagementControllerDeviceLocator(SdrCommon):
         self._device_id_string(buffer)
 
 
+###
+# SDR type 0x13
+##################################################
+class SdrManagementControllerConfirmationRecord(SdrCommon):
+    def __init__(self, data=None, next_id=None):
+        super(SdrManagementControllerConfirmationRecord, self).__init__(
+                data, next_id)
+
+    def _from_data(self, data):
+        buffer = ByteBuffer(data[5:])
+        self.device_slave_address = buffer.pop_unsigned_int(1) >> 1
+        self.device_id = buffer.pop_unsigned_int(1)
+        self.channel_number = buffer.pop_unsigned_int(1)
+        self.firmware_revision_1 = buffer.pop_unsigned_int(1)
+        self.firmware_revision_2 = buffer.pop_unsigned_int(1)
+        self.ipmi_version = buffer.pop_unsigned_int(1)
+        self.manufacturer_id = buffer.pop_unsigned_int(3) & 0xfffff
+        self.product_id = buffer.pop_unsigned_int(2)
+        self.device_guid = buffer.pop_unsigned_int(16)
+
+
 ###
 # SDR type 0xC0
 ##################################################
