@@ -33,6 +33,7 @@ EVENT_READING_TYPE_CODE_STATE = 0x03
 EVENT_READING_TYPE_CODE_PREDICTIVE_FAILURE = 0x04
 EVENT_READING_TYPE_CODE_LIMIT = 0x05
 EVENT_READING_TYPE_CODE_PERFORMANCE = 0x06
+EVENT_READING_TYPE_SENSOR_SPECIFIC = 0x6f
 
 # Sensor Types
 SENSOR_TYPE_TEMPERATURE = 0x01
@@ -211,3 +212,14 @@ class Sensor(object):
                 if getattr(rsp.readable_mask, threshold):
                     thresholds[threshold] = getattr(rsp.threshold, threshold)
         return thresholds
+
+    def send_platform_event(self, sensor_type, sensor_number, event_type,
+                            asserted=True, event_data=None):
+        req = create_request_by_name('PlatformEvent')
+        req.sensor_type = sensor_type
+        req.sensor_number = sensor_number
+        req.event_type.type = event_type
+        req.event_type.dir = 0 if asserted else 1
+        req.event_data = [0] if event_data is None else event_data
+        rsp = self.send_message(req)
+        check_completion_code(rsp.completion_code)
