@@ -12,9 +12,12 @@ class ResponseDecoder(object):
 
 
 class State(DefaultProperties, ResponseDecoder):
-    """This is a container that represents a state. The state can have default
+    """This is a container that represents a state.
+
+    The state can have default
     properties that are created by init.
     """
+
     def __init__(self, rsp=None):
         DefaultProperties.__init__(self)
         ResponseDecoder.__init__(self, rsp)
