@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import pytest
 from mock import MagicMock
-from nose.tools import eq_, raises
 
 from pyipmi.errors import IpmiTimeoutError, IpmiConnectionError
 from pyipmi.interfaces import Ipmitool
@@ -12,7 +12,7 @@ from pyipmi.utils import py3_array_tobytes
 
 class TestIpmitool:
 
-    def setup(self):
+    def setup_method(self):
         self._interface = Ipmitool(interface_type='lan')
         self.session = Session()
         self.session.interface = self._interface
@@ -23,19 +23,24 @@ class TestIpmitool:
     def test_build_ipmitool_target_ipmb_address(self):
         target = Target(0xb0)
         cmd = self._interface._build_ipmitool_target(target)
-        eq_(cmd, ' -t 0xb0')
+        assert cmd == ' -t 0xb0'
 
     def test_build_ipmitool_target_routing_2(self):
         target = Target(routing=[(0x81, 0x20, 7), (0x20, 0x82, 0)])
         cmd = self._interface._build_ipmitool_target(target)
-        eq_(cmd, ' -t 0x82 -b 7')
+        assert cmd == ' -t 0x82 -b 7'
 
     def test_build_ipmitool_target_routing_3(self):
         target = Target(routing=[(0x81, 0x20, 0),
                                  (0x20, 0x82, 7),
                                  (0x20, 0x72, None)])
         cmd = self._interface._build_ipmitool_target(target)
-        eq_(cmd, ' -T 0x82 -B 0 -t 0x72 -b 7')
+        assert cmd == ' -T 0x82 -B 0 -t 0x72 -b 7'
+
+    def test_build_ipmitool_target_routing_4(self):
+        target = None
+        cmd = self._interface._build_ipmitool_target(target)
+        assert cmd == ''
 
     def test_send_and_receive(self):
         pass
@@ -99,8 +104,8 @@ class TestIpmitool:
         target = Target(0x20)
         data = self._interface.send_and_receive_raw(target, 0, 0x6, b'\x01')
 
-        eq_(data, b'\x00\x10\x80\x01\x02\x51\xbd\x98\x3a\x00\xa8\x06'
-                  b'\x00\x03\x00\x00')
+        assert data == b'\x00\x10\x80\x01\x02\x51\xbd\x98' \
+                       b'\x3a\x00\xa8\x06\x00\x03\x00\x00'
 
     def test_send_and_receive_raw_completion_code_timeout(self):
         mock = MagicMock()
@@ -112,7 +117,7 @@ class TestIpmitool:
         self._interface._run_ipmitool = mock
         data = self._interface.send_and_receive_raw(target, 0, 0x6, b'\x01')
 
-        eq_(data, b'\xc3')
+        assert data == b'\xc3'
 
     def test_send_and_receive_raw_completion_code_not_ok(self):
         mock = MagicMock()
@@ -124,9 +129,8 @@ class TestIpmitool:
         self._interface._run_ipmitool = mock
         data = self._interface.send_and_receive_raw(target, 0, 0x6, b'\x01')
 
-        eq_(data, b'\xcc')
+        assert data == b'\xcc'
 
-    @raises(IpmiTimeoutError)
     def test_send_and_receive_raw_timeout_without_response(self):
         mock = MagicMock()
         mock.return_value = (b'Unable to send RAW command '
@@ -134,7 +138,8 @@ class TestIpmitool:
 
         target = Target(0x20)
         self._interface._run_ipmitool = mock
-        self._interface.send_and_receive_raw(target, 0, 0x6, b'\x01')
+        with pytest.raises(IpmiTimeoutError):
+            self._interface.send_and_receive_raw(target, 0, 0x6, b'\x01')
 
     def test_send_and_receive_raw_serial(self):
         interface = Ipmitool(interface_type='serial-terminal')
@@ -155,44 +160,44 @@ class TestIpmitool:
     def test_parse_output_rsp(self):
         test_str = b' 12 34 56 78 \r\n d0 0f af fe de ad be ef\naa 55\r\nbb    \n'
         cc, rsp = self._interface._parse_output(test_str)
-        eq_(cc, None)
-        eq_(py3_array_tobytes(rsp), b'\x12\x34\x56\x78\xd0\x0f\xaf\xfe\xde\xad\xbe\xef\xaa\x55\xbb')
+        assert cc is None
+        assert py3_array_tobytes(rsp) == b'\x12\x34\x56\x78\xd0\x0f\xaf\xfe\xde\xad\xbe\xef\xaa\x55\xbb'
 
     def test_parse_output_rsp_suppressed_error(self):
         test_str = b'Get HPM.x Capabilities request failed, compcode = c9\n'\
                    b' 12 34 56 78 \r\n d0 0f af fe de ad be ef\naa 55\r\nbb    \n'
         cc, rsp = self._interface._parse_output(test_str)
-        eq_(cc, None)
-        eq_(py3_array_tobytes(rsp), b'\x12\x34\x56\x78\xd0\x0f\xaf\xfe\xde\xad\xbe\xef\xaa\x55\xbb')
+        assert cc is None
+        assert py3_array_tobytes(rsp) == b'\x12\x34\x56\x78\xd0\x0f\xaf\xfe\xde\xad\xbe\xef\xaa\x55\xbb'
 
     def test_parse_output_cc(self):
         test_str = b'Unable to send RAW command (channel=0x0 netfn=0x6 lun=0x0 cmd=0x1 rsp=0xcc): Ignore Me\n'
         cc, rsp = self._interface._parse_output(test_str)
-        eq_(cc, 0xcc)
-        eq_(rsp, None)
+        assert cc == 0xcc
+        assert rsp is None
 
     def test_parse_output_cc_suppressed_error(self):
         test_str = b'Get HPM.x Capabilities request failed, compcode = c9\n'\
                    b'Unable to send RAW command (channel=0x0 netfn=0x6 lun=0x0 cmd=0x1 rsp=0xcc): Ignore Me\n'
         cc, rsp = self._interface._parse_output(test_str)
-        eq_(cc, 0xcc)
-        eq_(rsp, None)
+        assert cc == 0xcc
+        assert rsp is None
 
-    @raises(IpmiConnectionError)
     def test_parse_output_connection_error_rmcp_plus(self):
         test_str = b'Error: Unable to establish IPMI v2 / RMCP+ session\n'
-        cc, rsp = self._interface._parse_output(test_str)
-        eq_(cc, 0xcc)
-        eq_(rsp, None)
+        with pytest.raises(IpmiConnectionError):
+            cc, rsp = self._interface._parse_output(test_str)
+            assert cc == 0xcc
+            assert rsp is None
 
-    @raises(IpmiConnectionError)
     def test_parse_output_connection_error(self):
         test_str = b'Error: Unable to establish LAN session'
-        cc, rsp = self._interface._parse_output(test_str)
-        eq_(rsp, None)
+        with pytest.raises(IpmiConnectionError):
+            cc, rsp = self._interface._parse_output(test_str)
+            assert rsp is None
 
-    @raises(IpmiConnectionError)
     def test_parse_output_connection_error_rmcp(self):
         test_str = b'Error: Unable to establish IPMI v1.5 / RMCP session'
-        cc, rsp = self._interface._parse_output(test_str)
-        eq_(rsp, None)
+        with pytest.raises(IpmiConnectionError):
+            cc, rsp = self._interface._parse_output(test_str)
+            assert rsp is None
