@@ -1,7 +1,5 @@
 #!/usr/bin/env python
 
-from nose.tools import eq_
-
 import pyipmi.msgs.hpm
 
 from pyipmi.msgs import encode_message
@@ -13,14 +11,14 @@ def test_uploadfirmwareblockreq_encode():
     m.number = 1
     m.data = [0, 1, 2, 3]
     data = encode_message(m)
-    eq_(data, b'\x00\x01\x00\x01\x02\x03')
+    assert data == b'\x00\x01\x00\x01\x02\x03'
 
 
 def test_activatefirmwarereq_decode_valid_req():
     m = pyipmi.msgs.hpm.ActivateFirmwareReq()
     decode_message(m, b'\x00\x01')
-    eq_(m.picmg_identifier, 0)
-    eq_(m.rollback_override_policy, 1)
+    assert m.picmg_identifier == 0
+    assert m.rollback_override_policy == 1
 
 
 def test_activatefirmwarereq_encode_valid_req():
@@ -28,14 +26,14 @@ def test_activatefirmwarereq_encode_valid_req():
     m.picmg_identifier = 0
     m.rollback_override_policy = 0x1
     data = encode_message(m)
-    eq_(data, b'\x00\x01')
+    assert data == b'\x00\x01'
 
 
 def test_activatefirmwarereq_decode_valid_req_wo_optional():
     m = pyipmi.msgs.hpm.ActivateFirmwareReq()
     decode_message(m, b'\x00')
-    eq_(m.picmg_identifier, 0)
-    eq_(m.rollback_override_policy, None)
+    assert m.picmg_identifier == 0
+    assert m.rollback_override_policy is None
 
 
 def test_activatefirmwarereq_encode_valid_req_wo_optional():
@@ -43,4 +41,4 @@ def test_activatefirmwarereq_encode_valid_req_wo_optional():
     m.picmg_identifier = 0
     m.rollback_override_policy = None
     data = encode_message(m)
-    eq_(data, b'\x00')
+    assert data == b'\x00'
