@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from nose.tools import eq_, raises
+import pytest
 
 from pyipmi.fields import VersionField
 from pyipmi.errors import DecodingError
@@ -9,22 +9,20 @@ from pyipmi.errors import DecodingError
 
 def test_versionfield_object():
     version = VersionField([1, 0x99])
-    eq_(version.major, 1)
-    eq_(version.minor, 99)
+    assert version.major == 1
+    assert version.minor == 99
 
     version = VersionField('\x00\x99')
-    eq_(version.major, 0)
-    eq_(version.minor, 99)
+    assert version.major == 0
+    assert version.minor == 99
 
 
 def test_versionfield_invalid():
     version = VersionField('\x00\xff')
-    eq_(version.major, 0)
-    eq_(version.minor, 255)
+    assert version.major == 0
+    assert version.minor == 255
 
 
-@raises(DecodingError)
 def test_versionfield_decoding_error():
-    version = VersionField('\x00\x9a')
-    eq_(version.major, 0)
-    eq_(version.minor, 99)
+    with pytest.raises(DecodingError):
+        version = VersionField('\x00\x9a')  # noqa:F841
